yx_scope_flutter library
Classes
-
ScopeBuilder<
T> -
ScopeBuilder handles building a widget in response to
scope. -
ScopeConsumer<
T> - ScopeConsumer exposes a builder and listener in order react to new scope. ScopeConsumer is analogous to a nested ScopeListener and ScopeBuilder but reduces the amount of boilerplate needed. ScopeConsumer should only be used when it is necessary to both rebuild UI and execute other reactions to scope changes in the holder.
-
ScopeListener<
T> -
Takes a ScopeListener and an optional holder and invokes
the listener in response to
scopechanges in the holder. It should be used for functionality that needs to occur only in response to ascopechange such as navigation, showing aSnackBar, showing aDialog, etc... -
ScopeListenerState<
T> -
ScopeProvider<
T> - ScopeProvider is an InheritedWidget that passes your scope down to any widget in the subtree.
Typedefs
-
NonNullableScopeWidgetBuilder<
T> = Widget Function(BuildContext context, T scope) -
ScopeWidgetBuilder<
T> = Widget Function(BuildContext context, T? scope)